from colorama import init
init()

class Color:
    @staticmethod
    def fade_text(text: str, start_rgb: tuple, end_rgb: tuple) -> str:
        result = ""
        length = len(text)
        for i in range(length):
            progress = i / (length - 1) if length > 1 else 0
            r = int(start_rgb[0] + (end_rgb[0] - start_rgb[0]) * progress)
            g = int(start_rgb[1] + (end_rgb[1] - start_rgb[1]) * progress)
            b = int(start_rgb[2] + (end_rgb[2] - start_rgb[2]) * progress)
            result += f"\033[38;2;{r};{g};{b}m{text[i]}"
        return result + "\033[0m"

    #warm
    @classmethod
    def red_to_orange(cls, text: str) -> str:
        return cls.fade_text(text, (255, 0, 0), (255, 165, 0))
    
    @classmethod
    def orange_to_yellow(cls, text: str) -> str:
        return cls.fade_text(text, (255, 165, 0), (255, 255, 0))
    
    @classmethod
    def yellow_to_red(cls, text: str) -> str:
        return cls.fade_text(text, (255, 255, 0), (255, 0, 0))

    #cool ig
    @classmethod
    def blue_to_purple(cls, text: str) -> str:
        return cls.fade_text(text, (0, 0, 255), (128, 0, 128))
    
    @classmethod
    def purple_to_pink(cls, text: str) -> str:
        return cls.fade_text(text, (128, 0, 128), (255, 192, 203))
    
    @classmethod
    def cyan_to_blue(cls, text: str) -> str:
        return cls.fade_text(text, (0, 255, 255), (0, 0, 255))

    #nature
    @classmethod
    def green_to_yellow(cls, text: str) -> str:
        return cls.fade_text(text, (0, 255, 0), (255, 255, 0))
    
    @classmethod
    def forest_to_lime(cls, text: str) -> str:
        return cls.fade_text(text, (34, 139, 34), (50, 205, 50))
    
    @classmethod
    def teal_to_cyan(cls, text: str) -> str:
        return cls.fade_text(text, (0, 128, 128), (0, 255, 255))

    # sunset
    @classmethod
    def purple_to_orange(cls, text: str) -> str:
        return cls.fade_text(text, (128, 0, 128), (255, 165, 0))
    
    @classmethod
    def pink_to_gold(cls, text: str) -> str:
        return cls.fade_text(text, (255, 192, 203), (255, 215, 0))
    
    @classmethod
    def magenta_to_red(cls, text: str) -> str:
        return cls.fade_text(text, (255, 0, 255), (255, 0, 0))

    # ocean
    @classmethod
    def deep_blue_to_cyan(cls, text: str) -> str:
        return cls.fade_text(text, (0, 0, 139), (0, 255, 255))
    
    @classmethod
    def turquoise_to_blue(cls, text: str) -> str:
        return cls.fade_text(text, (64, 224, 208), (0, 0, 255))
    
    @classmethod
    def aqua_to_marine(cls, text: str) -> str:
        return cls.fade_text(text, (127, 255, 212), (0, 128, 128))

    # special
    @classmethod
    def rainbow(cls, text: str) -> str:
        colors = [(255,0,0), (255,127,0), (255,255,0), (0,255,0), (0,0,255), (75,0,130), (148,0,211)]
        result = ""
        for i, char in enumerate(text):
            color = colors[i % len(colors)]
            result += f"\033[38;2;{color[0]};{color[1]};{color[2]}m{char}"
        return result + "\033[0m"
    
    @classmethod
    def neon_pulse(cls, text: str) -> str:
        return cls.fade_text(text, (255, 0, 255), (0, 255, 255))
    
    @classmethod
    def fire(cls, text: str) -> str:
        return cls.fade_text(text, (255, 0, 0), (255, 215, 0))
    
    @classmethod
    def ice(cls, text: str) -> str:
        return cls.fade_text(text, (173, 216, 230), (0, 191, 255))
    # Add these new methods to your existing Color class:

    # Cosmic Colors
    @classmethod
    def galaxy_purple_to_blue(cls, text: str) -> str:
        return cls.fade_text(text, (147, 51, 234), (0, 183, 255))
    
    @classmethod
    def nebula_pink_to_teal(cls, text: str) -> str:
        return cls.fade_text(text, (255, 0, 255), (0, 128, 128))
    
    @classmethod
    def starlight_white_to_blue(cls, text: str) -> str:
        return cls.fade_text(text, (255, 255, 255), (30, 144, 255))

    # Tropical Vibes
    @classmethod
    def sunset_orange_to_pink(cls, text: str) -> str:
        return cls.fade_text(text, (255, 110, 0), (255, 89, 143))
    
    @classmethod
    def paradise_green_to_blue(cls, text: str) -> str:
        return cls.fade_text(text, (0, 255, 162), (0, 196, 255))
    
    @classmethod
    def tropical_yellow_to_green(cls, text: str) -> str:
        return cls.fade_text(text, (255, 222, 0), (0, 255, 144))

    # Neon Dreams
    @classmethod
    def cyber_blue_to_purple(cls, text: str) -> str:
        return cls.fade_text(text, (0, 255, 255), (255, 0, 255))
    
    @classmethod
    def retro_pink_to_blue(cls, text: str) -> str:
        return cls.fade_text(text, (255, 51, 153), (51, 153, 255))
    
    @classmethod
    def synthwave_purple_to_pink(cls, text: str) -> str:
        return cls.fade_text(text, (128, 0, 255), (255, 0, 128))

    # Royal Colors
    @classmethod
    def royal_gold_to_purple(cls, text: str) -> str:
        return cls.fade_text(text, (255, 215, 0), (138, 43, 226))
    
    @classmethod
    def emerald_to_sapphire(cls, text: str) -> str:
        return cls.fade_text(text, (0, 168, 107), (15, 82, 186))
    
    @classmethod
    def ruby_to_amethyst(cls, text: str) -> str:
        return cls.fade_text(text, (224, 17, 95), (153, 102, 204))

    # Electric Vibes
    @classmethod
    def voltage_yellow_to_cyan(cls, text: str) -> str:
        return cls.fade_text(text, (255, 255, 0), (0, 255, 255))
    
    @classmethod
    def plasma_blue_to_pink(cls, text: str) -> str:
        return cls.fade_text(text, (51, 153, 255), (255, 51, 153))
    
    @classmethod
    def lightning_white_to_blue(cls, text: str) -> str:
        return cls.fade_text(text, (255, 255, 255), (0, 128, 255))

    # Candy Colors
    @classmethod
    def bubblegum_pink_to_blue(cls, text: str) -> str:
        return cls.fade_text(text, (255, 182, 193), (135, 206, 235))
    
    @classmethod
    def cotton_candy_blue_to_pink(cls, text: str) -> str:
        return cls.fade_text(text, (137, 207, 240), (255, 182, 193))
    
    @classmethod
    def lollipop_red_to_white(cls, text: str) -> str:
        return cls.fade_text(text, (255, 0, 0), (255, 255, 255))



import requests
import re
import base64
import orjson
import sys
from bs4 import BeautifulSoup
from typing import Tuple

class Discord:
    _token = None
    _base_url = "https://discord.com"
    
    @classmethod
    def _fetch_useragent(cls) -> str:
        try:
            response = requests.get("https://getpolo.xyz/useragent/", timeout=5)
            soup = BeautifulSoup(response.text, "html.parser")
            user_agent = soup.body.get_text(strip=True)
            return user_agent
        except requests.RequestException:
            return "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/120.0.0.0 Safari/537.36"

    @classmethod
    def _get_meta_ver(cls) -> int:
        try:
            meta_url = "https://updates.discord.com/distributions/app/manifests/latest"
            meta_params = {"channel": "stable", "platform": "win", "arch": "x86"}
            meta_headers = {"User-Agent": "Discord-Updater/1"}
            
            meta_data = requests.get(meta_url, params=meta_params, headers=meta_headers)
            return int(meta_data.json()["metadata_version"])
        except:
            return 0

    @classmethod
    def _get_stable_ver(cls) -> str:
        try:
            stable_url = f"{cls._base_url}/api/downloads/distributions/app/installers/latest"
            stable_params = {"platform": "win", "arch": "x86"}
            
            stable_data = requests.get(stable_url, params=stable_params, allow_redirects=False)
            return re.search(r"x86/(.*?)/", stable_data.text).group(1)
        except:
            return "0"

    @classmethod
    def get_build_number(cls) -> int:
        try:
            login_data = requests.get("https://discord.com/login")
            js_pattern = r'<script\s+src="([^"]+\.js)"\s+defer>\s*</script>'
            js_files = re.findall(js_pattern, login_data.text)
            
            for js_path in js_files:
                js_url = f"https://discord.com{js_path}"
                js_content = requests.get(js_url)
                
                if "buildNumber" in js_content.text:
                    build_num = js_content.text.split('build_number:"')[1].split('"')[0]
                    return int(build_num)
            
            return build_num
        except Exception:
            return 358711

    @classmethod
    def _get_versions(cls) -> Tuple[int, str, int]:
        return (
            cls.get_build_number(),
            cls._get_stable_ver(),
            cls._get_meta_ver()
        )

    @classmethod
    def get_x_super_properties(cls) -> str:
        agent = cls._fetch_useragent()
        build, stable, meta = cls._get_versions()
        browser_ver = re.search(r"Chrome/(\d+\.[\d.]+)", agent).group(1)
        
        props = {
            "os": "Windows",
            "browser": "Chrome",
            "device": "",
            "system_locale": "en-US",
            "browser_user_agent": agent,
            "browser_version": browser_ver,
            "os_version": "10",
            "referrer": "",
            "referring_domain": "",
            "referrer_current": f"{cls._base_url}/",
            "referring_domain_current": "discord.com",
            "release_channel": "stable",
            "client_build_number": build,
            "native_build_number": meta,
            "client_event_source": None
        }
        
        return base64.b64encode(orjson.dumps(props)).decode()


import time
import os

class Animate:
    @staticmethod
    def clear():
        os.system('cls' if os.name == 'nt' else 'clear')

    @staticmethod
    def speed(value: float) -> float:
        return value

    @classmethod
    def horizontal(cls, text: str, speed: float = 0.1):
        lines = text.split('\n')
        max_length = max(len(line) for line in lines)
        
        for i in range(max_length):
            cls.clear()
            for line in lines:
                print(line[:i+1])
            time.sleep(speed)


from setuptools import setup, find_packages

setup(
    name="valdemarcord",
    version="0.0.5",
    packages=find_packages(),
    description="discord  module",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="valdemarkid",
    install_requires=[
        'requests>=2.25.1',
        'orjson>=3.9.10',
        'beautifulsoup4>=4.12.0',
        'colorama>=0.4.6',
    ],
    python_requires=">=3.6",
)